@@ -7,12 +7,10 @@ our @ISA = "HollyGame::MapRoom";
 
 sub MapRoom {
 	my $class = shift;
-	my $self = {};
-	bless $self, $class;
 
-	$self = $self->SUPER::MapRoom;
+	$self = $class->SUPER::MapRoom;
 	$self->{@exits} = ();
 
-	return bless $self, $class;
+	return bless $self, ref($class) || $class;
 }
 
