@@ -11,11 +11,11 @@ sub PlayerExample {
 	$self->$app = shift;
 
 	my $image1 = new SDL::Surface(-name=>"./images/player.jpg");
-	$self->{imagelibrary}->push{$image1};
+	$self->{imagelibrary}->push($image1);
 	my $image2 = new SDL::Surface(-name=>"./images/player2.jpg");
-	$self->{imagelibrary}->push{$image1};
+	$self->{imagelibrary}->push($image2);
 	my $image3 = new SDL::Surface(-name=>"./images/player3.jpg");
-	$self->{imagelibrary}->push{$image1};
+	$self->{imagelibrary}->push($image3);
 
 	return bless $self, ref($class) || $class;	
 }
